summaryrefslogtreecommitdiff
path: root/app/Controller/Task.php
diff options
context:
space:
mode:
authorFrederic Guillot <fred@kanboard.net>2015-07-05 16:07:21 -0400
committerFrederic Guillot <fred@kanboard.net>2015-07-05 16:07:21 -0400
commitbb8b4c0e36afc05ff5b0cb3ac6465351a696b001 (patch)
treee7499d04cfe32ed429413c2bbe0c81c33700d36a /app/Controller/Task.php
parent67b9a56469b406b44cd1baad4445ddb6d707794f (diff)
Add task analytics
Diffstat (limited to 'app/Controller/Task.php')
-rw-r--r--app/Controller/Task.php11
1 files changed, 6 insertions, 5 deletions
diff --git a/app/Controller/Task.php b/app/Controller/Task.php
index dc83f7b1..b6e4845f 100644
--- a/app/Controller/Task.php
+++ b/app/Controller/Task.php
@@ -88,19 +88,20 @@ class Task extends Base
}
/**
* Display task activities
*
* @access public
*/
- public function activites()
+ public function analytics()
{
$task = $this->getTask();
- $this->response->html($this->taskLayout('task/activity', array(
+ $this->response->html($this->taskLayout('task/analytics', array(
'title' => $task['title'],
'task' => $task,
- 'ajax' => $this->request->isAjax(),
- 'events' => $this->projectActivity->getTask($task['id']),
+ 'lead_time' => $this->taskAnalytic->getLeadTime($task),
+ 'cycle_time' => $this->taskAnalytic->getCycleTime($task),
+ 'column_averages' => $this->taskAnalytic->getAverageTimeByColumn($task),
)));
}
@@ -88,19 +88,20 @@ class Task extends Base
}
/**
- * Display task activities
+ * Display task analytics
*
* @access public